@@ -24,7 +24,11 @@ def apply_env(cfg: dict) -> None:
         "workspace_uuid": "WORKSPACE_UUID",
         "region": "REGION",
         "project_id": "PROJECT_ID",
-    }
+        "secret_name": "SECRET_NAME",
+        "intellithing_key": "INTELLITHING_KEY",
+        "environment": "ENVIRONMENT",
+}
+
     for key, env in mapping.items():
         if key in cfg and cfg[key] is not None:
             os.environ[env] = str(cfg[key])
